@@ -3,59 +3,43 @@
  * Date        : 2008-04-17
  * Description : Sane plugin interface for KDE
  *
- * Copyright (C) 2008 by Kare Sars <kare dot sars at iki dot fi>
+ * SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  * ============================================================ */
 
 #include "sanedialog.h"
 
-#include <KLocalizedString>
 #include "kpLogCategories.h"
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <KWindowConfig>
-#include <KConfigGroup>
 
 #include <QPushButton>
 
 SaneDialog::SaneDialog(QWidget *parent)
     : KPageDialog(parent)
 {
-    setFaceType(static_cast<KPageDialog::FaceType> (Plain));
+    setFaceType(static_cast<KPageDialog::FaceType>(Plain));
     setWindowTitle(i18nc("@title:window", "Acquire Image"));
 
     buttonBox()->setStandardButtons(QDialogButtonBox::Close);
     buttonBox()->button(QDialogButtonBox::Close)->setDefault(true);
 
-
     m_ksanew = new KSaneIface::KSaneWidget(this);
     addPage(m_ksanew, QString());
 
-    connect (m_ksanew, &KSaneIface::KSaneWidget::scannedImageReady,
-             this, &SaneDialog::imageReady);
+    connect(m_ksanew, &KSaneIface::KSaneWidget::scannedImageReady, this, &SaneDialog::imageReady);
 
     m_openDev = QString();
 }
 
 bool SaneDialog::setup()
 {
-    if(!m_ksanew) {
+    if (!m_ksanew) {
         // new failed
         return false;
     }
@@ -65,7 +49,7 @@ bool SaneDialog::setup()
     // need to select a scanner
     m_openDev = m_ksanew->selectDevice(parentWidget());
     if (m_openDev.isEmpty()) {
-       // either no scanner was found or then cancel was pressed.
+        // either no scanner was found or then cancel was pressed.
         return false;
     }
     if (!m_ksanew->openDevice(m_openDev)) {
@@ -87,7 +71,7 @@ bool SaneDialog::setup()
         }
     }
 
-   return true;
+    return true;
 }
 
 SaneDialog::~SaneDialog()
