@@ -1,56 +1,34 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
 //
 // Tool methods for drawing shapes (subclasses reimplement most of these).
 //
 
-
 #define DEBUG_KP_TOOL 0
 
-
-#include "tools/kpTool.h"
 #include "kpToolPrivate.h"
+#include "tools/kpTool.h"
 
 #include <QApplication>
 
 #include "kpLogCategories.h"
 
 #include "environments/tools/kpToolEnvironment.h"
+#include "imagelib/kpPainter.h"
 #include "views/kpView.h"
 #include "views/manager/kpViewManager.h"
-#include "imagelib/kpPainter.h"
 
-#undef environ  // macro on win32
+#undef environ // macro on win32
 
 //---------------------------------------------------------------------
 
 // protected
-int kpTool::mouseButton () const
+int kpTool::mouseButton() const
 {
     return d->mouseButton;
 }
@@ -58,7 +36,7 @@ int kpTool::mouseButton () const
 //---------------------------------------------------------------------
 
 // protected
-bool kpTool::shiftPressed () const
+bool kpTool::shiftPressed() const
 {
     return d->shiftPressed;
 }
@@ -66,7 +44,7 @@ bool kpTool::shiftPressed () const
 //---------------------------------------------------------------------
 
 // protected
-bool kpTool::controlPressed () const
+bool kpTool::controlPressed() const
 {
     return d->controlPressed;
 }
@@ -74,14 +52,13 @@ bool kpTool::controlPressed () const
 //---------------------------------------------------------------------
 
 // protected
-bool kpTool::altPressed () const
+bool kpTool::altPressed() const
 {
     return d->altPressed;
 }
 
-
 // protected
-QPoint kpTool::startPoint () const
+QPoint kpTool::startPoint() const
 {
     return d->startPoint;
 }
@@ -89,7 +66,7 @@ QPoint kpTool::startPoint () const
 //---------------------------------------------------------------------
 
 // protected
-QPoint kpTool::currentPoint () const
+QPoint kpTool::currentPoint() const
 {
     // TODO: Q_ASSERT (hasBegun()) and similar in other accessors.
     //       We currently violate these kinds of invariants.
@@ -99,7 +76,7 @@ QPoint kpTool::currentPoint () const
 //---------------------------------------------------------------------
 
 // protected
-QPoint kpTool::currentViewPoint () const
+QPoint kpTool::currentViewPoint() const
 {
     return d->currentViewPoint;
 }
@@ -107,7 +84,7 @@ QPoint kpTool::currentViewPoint () const
 //---------------------------------------------------------------------
 
 // protected
-QRect kpTool::normalizedRect () const
+QRect kpTool::normalizedRect() const
 {
     return kpPainter::normalizedRect(d->startPoint, d->currentPoint);
 }
@@ -115,7 +92,7 @@ QRect kpTool::normalizedRect () const
 //---------------------------------------------------------------------
 
 // protected
-QPoint kpTool::lastPoint () const
+QPoint kpTool::lastPoint() const
 {
     return d->lastPoint;
 }
@@ -123,7 +100,7 @@ QPoint kpTool::lastPoint () const
 //---------------------------------------------------------------------
 
 // protected
-kpView *kpTool::viewUnderStartPoint () const
+kpView *kpTool::viewUnderStartPoint() const
 {
     return d->viewUnderStartPoint;
 }
@@ -131,34 +108,33 @@ kpView *kpTool::viewUnderStartPoint () const
 //---------------------------------------------------------------------
 
 // protected
-kpView *kpTool::viewUnderCursor () const
+kpView *kpTool::viewUnderCursor() const
 {
-    kpViewManager *vm = viewManager ();
-    return vm ? vm->viewUnderCursor () : nullptr;
+    kpViewManager *vm = viewManager();
+    return vm ? vm->viewUnderCursor() : nullptr;
 }
 
 //---------------------------------------------------------------------
 
-void kpTool::beginInternal ()
+void kpTool::beginInternal()
 {
 #if DEBUG_KP_TOOL
     qCDebug(kpLogTools) << "kpTool::beginInternal()";
 #endif
 
-    if (!d->began)
-    {
+    if (!d->began) {
         // clear leftover statusbar messages
-        setUserMessage ();
-        d->currentPoint = calculateCurrentPoint ();
-        d->currentViewPoint = calculateCurrentPoint (false/*view point*/);
-        setUserShapePoints (d->currentPoint);
+        setUserMessage();
+        d->currentPoint = calculateCurrentPoint();
+        d->currentViewPoint = calculateCurrentPoint(false /*view point*/);
+        setUserShapePoints(d->currentPoint);
 
         // TODO: Audit all the code in this file - states like "d->began" &
         //       "d->beganDraw" should be set before calling user func.
         //       Also, d->currentPoint should be more frequently initialised.
 
         // call user virtual func
-        begin ();
+        begin();
 
         // we've starting using the tool...
         d->began = true;
@@ -166,8 +142,7 @@ void kpTool::beginInternal ()
         // but we haven't started drawing with it
         d->beganDraw = false;
 
-
-        uint keyState = QApplication::keyboardModifiers ();
+        uint keyState = QApplication::keyboardModifiers();
 
         d->shiftPressed = (keyState & Qt::ShiftModifier);
         d->controlPressed = (keyState & Qt::ControlModifier);
@@ -181,21 +156,20 @@ void kpTool::beginInternal ()
 
 //---------------------------------------------------------------------
 
-void kpTool::endInternal ()
+void kpTool::endInternal()
 {
-    if (d->began)
-    {
+    if (d->began) {
         // before we can stop using the tool, we must stop the current drawing operation (if any)
-        if (hasBegunShape ()) {
-            endShapeInternal (d->currentPoint, normalizedRect ());
+        if (hasBegunShape()) {
+            endShapeInternal(d->currentPoint, normalizedRect());
         }
 
         // call user virtual func
-        end ();
+        end();
 
         // clear leftover statusbar messages
-        setUserMessage ();
-        setUserShapePoints (calculateCurrentPoint ());
+        setUserMessage();
+        setUserShapePoints(calculateCurrentPoint());
 
         // we've stopped using the tool...
         d->began = false;
@@ -203,14 +177,14 @@ void kpTool::endInternal ()
         // and so we can't be drawing with it
         d->beganDraw = false;
 
-        d->environ->hideAllToolWidgets ();
+        d->environ->hideAllToolWidgets();
     }
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::begin ()
+void kpTool::begin()
 {
 #if DEBUG_KP_TOOL
     qCDebug(kpLogTools) << "kpTool::begin() base implementation";
@@ -220,7 +194,7 @@ void kpTool::begin ()
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::end ()
+void kpTool::end()
 {
 #if DEBUG_KP_TOOL
     qCDebug(kpLogTools) << "kpTool::end() base implementation";
@@ -229,63 +203,68 @@ void kpTool::end ()
 
 //---------------------------------------------------------------------
 
-
-bool kpTool::hasBegun () const { return d->began; }
+bool kpTool::hasBegun() const
+{
+    return d->began;
+}
 
 //---------------------------------------------------------------------
 
-bool kpTool::hasBegunDraw () const { return d->beganDraw; }
+bool kpTool::hasBegunDraw() const
+{
+    return d->beganDraw;
+}
 
 //---------------------------------------------------------------------
 
 // virtual
-bool kpTool::hasBegunShape () const { return hasBegunDraw (); }
+bool kpTool::hasBegunShape() const
+{
+    return hasBegunDraw();
+}
 
 //---------------------------------------------------------------------
 
-
-void kpTool::beginDrawInternal ()
+void kpTool::beginDrawInternal()
 {
-    if (!d->beganDraw)
-    {
-        beginDraw ();
+    if (!d->beganDraw) {
+        beginDraw();
 
         d->beganDraw = true;
-        Q_EMIT beganDraw (d->currentPoint);
+        Q_EMIT beganDraw(d->currentPoint);
     }
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::beginDraw ()
+void kpTool::beginDraw()
 {
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::hover (const QPoint &point)
+void kpTool::hover(const QPoint &point)
 {
 #if DEBUG_KP_TOOL
-    qCDebug(kpLogTools) << "kpTool::hover" << point
-               << " base implementation";
+    qCDebug(kpLogTools) << "kpTool::hover" << point << " base implementation";
 #endif
 
-    setUserShapePoints (point);
+    setUserShapePoints(point);
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::globalDraw ()
+void kpTool::globalDraw()
 {
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::reselect ()
+void kpTool::reselect()
 {
 #if DEBUG_KP_TOOL
     qCDebug(kpLogTools) << "kpTool::reselect() base implementation";
@@ -294,47 +273,41 @@ void kpTool::reselect ()
 
 //---------------------------------------------------------------------
 
-
 // virtual
-void kpTool::draw (const QPoint &, const QPoint &, const QRect &)
+void kpTool::draw(const QPoint &, const QPoint &, const QRect &)
 {
 }
 
 //---------------------------------------------------------------------
 
 // private
-void kpTool::drawInternal ()
+void kpTool::drawInternal()
 {
-    draw (d->currentPoint, d->lastPoint, normalizedRect ());
+    draw(d->currentPoint, d->lastPoint, normalizedRect());
 }
 
 //---------------------------------------------------------------------
 
-
 // also called by kpView
-void kpTool::cancelShapeInternal ()
+void kpTool::cancelShapeInternal()
 {
-    if (hasBegunShape ())
-    {
+    if (hasBegunShape()) {
         d->beganDraw = false;
-        cancelShape ();
+        cancelShape();
         d->viewUnderStartPoint = nullptr;
 
-        Q_EMIT cancelledShape (viewUnderCursor () ? d->currentPoint : KP_INVALID_POINT);
+        Q_EMIT cancelledShape(viewUnderCursor() ? d->currentPoint : KP_INVALID_POINT);
 
-        if (viewUnderCursor ()) {
-            hover (d->currentPoint);
-        }
-        else
-        {
+        if (viewUnderCursor()) {
+            hover(d->currentPoint);
+        } else {
             d->currentPoint = KP_INVALID_POINT;
             d->currentViewPoint = KP_INVALID_POINT;
-            hover (d->currentPoint);
+            hover(d->currentPoint);
         }
 
-        if (returnToPreviousToolAfterEndDraw ())
-        {
-            d->environ->selectPreviousTool ();
+        if (returnToPreviousToolAfterEndDraw()) {
+            d->environ->selectPreviousTool();
         }
     }
 }
@@ -342,81 +315,74 @@ void kpTool::cancelShapeInternal ()
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::cancelShape ()
+void kpTool::cancelShape()
 {
-    qCWarning(kpLogTools) << "Tool cannot cancel operation!" ;
+    qCWarning(kpLogTools) << "Tool cannot cancel operation!";
 }
 
 //---------------------------------------------------------------------
 
-void kpTool::releasedAllButtons ()
+void kpTool::releasedAllButtons()
 {
 }
 
 //---------------------------------------------------------------------
 
-void kpTool::endDrawInternal (const QPoint &thisPoint, const QRect &normalizedRect,
-                              bool wantEndShape)
+void kpTool::endDrawInternal(const QPoint &thisPoint, const QRect &normalizedRect, bool wantEndShape)
 {
 #if DEBUG_KP_TOOL && 1
     qCDebug(kpLogTools) << "kpTool::endDrawInternal() wantEndShape=" << wantEndShape;
 #endif
 
-    if (wantEndShape && !hasBegunShape ()) {
+    if (wantEndShape && !hasBegunShape()) {
         return;
     }
 
-    if (!wantEndShape && !hasBegunDraw ()) {
+    if (!wantEndShape && !hasBegunDraw()) {
         return;
     }
 
     d->beganDraw = false;
 
-    if (wantEndShape)
-    {
-    #if DEBUG_KP_TOOL && 0
+    if (wantEndShape) {
+#if DEBUG_KP_TOOL && 0
         qCDebug(kpLogTools) << "\tcalling endShape()";
-    #endif
-        endShape (thisPoint, normalizedRect);
-    }
-    else
-    {
-    #if DEBUG_KP_TOOL && 0
+#endif
+        endShape(thisPoint, normalizedRect);
+    } else {
+#if DEBUG_KP_TOOL && 0
         qCDebug(kpLogTools) << "\tcalling endDraw()";
-    #endif
-        endDraw (thisPoint, normalizedRect);
+#endif
+        endDraw(thisPoint, normalizedRect);
     }
     d->viewUnderStartPoint = nullptr;
 
-    Q_EMIT endedDraw (d->currentPoint);
-    if (viewUnderCursor ()) {
-        hover (d->currentPoint);
-    }
-    else
-    {
+    Q_EMIT endedDraw(d->currentPoint);
+    if (viewUnderCursor()) {
+        hover(d->currentPoint);
+    } else {
         d->currentPoint = KP_INVALID_POINT;
         d->currentViewPoint = KP_INVALID_POINT;
-        hover (d->currentPoint);
+        hover(d->currentPoint);
     }
 
-    if (returnToPreviousToolAfterEndDraw ())
-    {
-        d->environ->selectPreviousTool ();
+    if (returnToPreviousToolAfterEndDraw()) {
+        d->environ->selectPreviousTool();
     }
 }
 
 //---------------------------------------------------------------------
 
 // private
-void kpTool::endShapeInternal (const QPoint &thisPoint, const QRect &normalizedRect)
+void kpTool::endShapeInternal(const QPoint &thisPoint, const QRect &normalizedRect)
 {
-    endDrawInternal (thisPoint, normalizedRect, true/*end shape*/);
+    endDrawInternal(thisPoint, normalizedRect, true /*end shape*/);
 }
 
 //---------------------------------------------------------------------
 
 // virtual
-void kpTool::endDraw (const QPoint &, const QRect &)
+void kpTool::endDraw(const QPoint &, const QRect &)
 {
 }
 
